@@ -1,3 +1,4 @@
+// clang-format off
 /**
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -5,6 +6,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
+// clang-format on
 
 #ifndef FILEACCESSJOBHANDLER_H
 #define FILEACCESSJOBHANDLER_H
@@ -14,7 +16,7 @@
 #include <QObject>
 #include <QString>
 
-#ifndef AUTOTEST
+#if HAS_KFKIO && !defined AUTOTEST
 #include <KIO/UDSEntry>
 #endif
 
@@ -34,9 +36,9 @@ class FileAccessJobHandler: public QObject
 
     virtual FileAccessJobHandler* copy(FileAccess* fileAccess) = 0;
     //This exists soley to allow FileAccess to be no-except movable
-    void setFileAccess(FileAccess* pFileAccess) {  mFileAccess = pFileAccess; }
+    void setFileAccess(FileAccess* pFileAccess) noexcept {  mFileAccess = pFileAccess; }
     virtual bool get(void* pDestBuffer, long maxLength) = 0;
-    virtual bool put(const void* pSrcBuffer, long maxLength, bool bOverwrite, bool bResume = false, int permissions = -1) = 0;
+    virtual bool put(const void* pSrcBuffer, long maxLength, bool bOverwrite, bool bResume = false, qint32 permissions = -1) = 0;
     virtual bool stat(bool bWantToWrite = false) = 0;
     virtual bool copyFile(const QString& dest) = 0;
     virtual bool rename(const FileAccess& dest) = 0;
